@@ -398,10 +398,73 @@ class BlockDialog(QtGui.QDialog):
 		self.setup()
 
 	def setup(self):
-		for x in [1, 2, 4, 8, 16, 32, 64, 128]:
+		for x in ["From movement", 1, 2, 4, 8, 16, 32, 64, 128]:
 			self.ui.resolution.addItem(str(x))
-		for x in diatonic.basic_keys:
+		for x in ["From movement"] + diatonic.basic_keys:
 			self.ui.key.addItem(x)
+		for x in Options.get_available_blocks():
+			self.ui.blockcombo.addItem(x)
+
+		self.connect(self.ui.buttonBox,
+			QtCore.SIGNAL("accepted()"),
+			lambda: self.save_block())
+
+	def load_block(self, block_str):
+
+		p = block_str.split(" ")
+		self.ui.blockcombo.setCurrentIndex(combo_index_by_text(self.ui.blockcombo, p[0]))
+
+		if len(p) == 1:
+			return 
+
+		params = Options.parse_block_params(p[1:])
+		if 'duration' in params:
+			self.ui.duration.setValue(params['duration'])
+		if 'bpm' in params:
+			self.ui.bpm.setValue(params["bpm"])
+		if 'wild' in params:
+			self.ui.wildness.setValue(params["wild"])
+		if 'swing' in params:
+			self.ui.swing.setChecked(True)
+		if 'key' in params:
+			self.ui.key.setCurrentIndex(combo_index_by_text(self.ui.key, params["key"]))
+		if 'resolution' in params:
+			self.ui.resolution.setCurrentIndex(combo_index_by_text(self.ui.resolution, str(params["resolution"])))
+
+
+
+	def save_block(self):
+	
+		block = self.ui.blockcombo.currentText()
+		res = str(block) + " { "
+
+		bpm = self.ui.bpm.value()
+		resolution = str(self.ui.resolution.currentText())
+		key = str(self.ui.key.currentText())
+		wild = self.ui.wildness.value()
+		duration = self.ui.duration.value()
+		swing = self.ui.swing.isChecked()
+
+		if bpm != 0:
+			res += "bpm:%d " % bpm
+		if wild != 0.0:
+			res += "wild:%f " % wild
+		if duration != 0:
+			res += "duration:%d " % duration
+		
+		if swing:
+			res += "swing "
+		if resolution != "From movement":
+			res += "resolution:%s " % resolution
+		if key != "From movement":
+			res += "key:%s " % key
+
+		
+		
+		res += "}"
+		if res == str(block) + " { }":
+			res = str(block)
+		self.item.setText(res)
 
 class ImproviserMainWindow(QtGui.QMainWindow):
 
@@ -584,6 +647,7 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		if cur is None:
 			return
 		b = BlockDialog(self.ui.blocks.currentItem())
+		b.load_block(str(cur.text()))
 		b.show()
 		b.exec_()
 
@@ -633,7 +697,8 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 	def get_blocks(self):
 		res = ""
 		for x in range(self.ui.blocks.count()):
-			res += str(self.ui.blocks.item(x).text()) + ","
+			t = str(self.ui.blocks.item(x).text())
+			res += t + ","
 		return res[:-1]
 	
 	def show_about(self):
@@ -729,7 +794,9 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		if o.blocks != "":
 			bloc = o.blocks.split(",")
 			for b in bloc:
-				if b in Options.get_available_blocks():
+				parts = b.split(" ")
+				block = parts[0]
+				if block in Options.get_available_blocks():
 					self.ui.blocks.addItem(b)
 		if o.instrument != "":
 			instr = o.instrument.split(",")
